@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2011 OpenStack Foundation
 # Copyright 2013 Rackspace Hosting
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
@@ -17,8 +15,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from testtools import TestCase
-from mock import Mock
+import testtools
+import mock
 
 from troveclient.v1 import accounts
 from troveclient import base
@@ -28,12 +26,12 @@ Unit tests for accounts.py
 """
 
 
-class AccountTest(TestCase):
+class AccountTest(testtools.TestCase):
 
     def setUp(self):
         super(AccountTest, self).setUp()
         self.orig__init = accounts.Account.__init__
-        accounts.Account.__init__ = Mock(return_value=None)
+        accounts.Account.__init__ = mock.Mock(return_value=None)
         self.account = accounts.Account()
 
     def tearDown(self):
@@ -45,15 +43,15 @@ class AccountTest(TestCase):
         self.assertEqual('<Account: account-1>', self.account.__repr__())
 
 
-class AccountsTest(TestCase):
+class AccountsTest(testtools.TestCase):
 
     def setUp(self):
         super(AccountsTest, self).setUp()
         self.orig__init = accounts.Accounts.__init__
-        accounts.Accounts.__init__ = Mock(return_value=None)
+        accounts.Accounts.__init__ = mock.Mock(return_value=None)
         self.accounts = accounts.Accounts()
-        self.accounts.api = Mock()
-        self.accounts.api.client = Mock()
+        self.accounts.api = mock.Mock()
+        self.accounts.api.client = mock.Mock()
 
     def tearDown(self):
         super(AccountsTest, self).tearDown()
@@ -63,33 +61,33 @@ class AccountsTest(TestCase):
         def side_effect_func(self, val):
             return val
 
-        self.accounts.resource_class = Mock(side_effect=side_effect_func)
+        self.accounts.resource_class = mock.Mock(side_effect=side_effect_func)
         key_ = 'key'
         body_ = {key_: "test-value"}
-        self.accounts.api.client.get = Mock(return_value=('resp', body_))
+        self.accounts.api.client.get = mock.Mock(return_value=('resp', body_))
         self.assertEqual("test-value", self.accounts._list('url', key_))
 
-        self.accounts.api.client.get = Mock(return_value=('resp', None))
+        self.accounts.api.client.get = mock.Mock(return_value=('resp', None))
         self.assertRaises(Exception, self.accounts._list, 'url', None)
 
     def test_index(self):
-        resp = Mock()
+        resp = mock.Mock()
         resp.status_code = 400
         body = {"Accounts": {}}
-        self.accounts.api.client.get = Mock(return_value=(resp, body))
+        self.accounts.api.client.get = mock.Mock(return_value=(resp, body))
         self.assertRaises(Exception, self.accounts.index)
         resp.status_code = 200
         self.assertTrue(isinstance(self.accounts.index(), base.Resource))
-        self.accounts.api.client.get = Mock(return_value=(resp, None))
+        self.accounts.api.client.get = mock.Mock(return_value=(resp, None))
         self.assertRaises(Exception, self.accounts.index)
 
     def test_show(self):
         def side_effect_func(acct_name, acct):
             return acct_name, acct
 
-        account_ = Mock()
+        account_ = mock.Mock()
         account_.name = "test-account"
-        self.accounts._list = Mock(side_effect=side_effect_func)
+        self.accounts._list = mock.Mock(side_effect=side_effect_func)
         self.assertEqual(('/mgmt/accounts/test-account', 'account'),
                          self.accounts.show(account_))
 
@@ -97,7 +95,7 @@ class AccountsTest(TestCase):
         account_ = 'account with no name'
         self.assertEqual(account_,
                          accounts.Accounts._get_account_name(account_))
-        account_ = Mock()
+        account_ = mock.Mock()
         account_.name = "account-name"
         self.assertEqual("account-name",
                          accounts.Accounts._get_account_name(account_))
