@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2011 OpenStack Foundation
 # Copyright 2013 Rackspace Hosting
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
@@ -17,8 +15,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from testtools import TestCase
-from mock import Mock
+import testtools
+import mock
 
 from troveclient.v1 import instances
 from troveclient import base
@@ -28,14 +26,14 @@ Unit tests for instances.py
 """
 
 
-class InstanceTest(TestCase):
+class InstanceTest(testtools.TestCase):
 
     def setUp(self):
         super(InstanceTest, self).setUp()
         self.orig__init = instances.Instance.__init__
-        instances.Instance.__init__ = Mock(return_value=None)
+        instances.Instance.__init__ = mock.Mock(return_value=None)
         self.instance = instances.Instance()
-        self.instance.manager = Mock()
+        self.instance.manager = mock.Mock()
 
     def tearDown(self):
         super(InstanceTest, self).tearDown()
@@ -47,37 +45,37 @@ class InstanceTest(TestCase):
 
     def test_list_databases(self):
         db_list = ['database1', 'database2']
-        self.instance.manager.databases = Mock()
-        self.instance.manager.databases.list = Mock(return_value=db_list)
+        self.instance.manager.databases = mock.Mock()
+        self.instance.manager.databases.list = mock.Mock(return_value=db_list)
         self.assertEqual(db_list, self.instance.list_databases())
 
     def test_delete(self):
-        db_delete_mock = Mock(return_value=None)
+        db_delete_mock = mock.Mock(return_value=None)
         self.instance.manager.delete = db_delete_mock
         self.instance.delete()
         self.assertEqual(1, db_delete_mock.call_count)
 
     def test_restart(self):
-        db_restart_mock = Mock(return_value=None)
+        db_restart_mock = mock.Mock(return_value=None)
         self.instance.manager.restart = db_restart_mock
         self.instance.id = 1
         self.instance.restart()
         self.assertEqual(1, db_restart_mock.call_count)
 
 
-class InstancesTest(TestCase):
+class InstancesTest(testtools.TestCase):
 
     def setUp(self):
         super(InstancesTest, self).setUp()
         self.orig__init = instances.Instances.__init__
-        instances.Instances.__init__ = Mock(return_value=None)
+        instances.Instances.__init__ = mock.Mock(return_value=None)
         self.instances = instances.Instances()
-        self.instances.api = Mock()
-        self.instances.api.client = Mock()
-        self.instances.resource_class = Mock(return_value="instance-1")
+        self.instances.api = mock.Mock()
+        self.instances.api.client = mock.Mock()
+        self.instances.resource_class = mock.Mock(return_value="instance-1")
 
         self.orig_base_getid = base.getid
-        base.getid = Mock(return_value="instance1")
+        base.getid = mock.Mock(return_value="instance1")
 
     def tearDown(self):
         super(InstancesTest, self).tearDown()
@@ -88,66 +86,59 @@ class InstancesTest(TestCase):
         def side_effect_func(path, body, inst):
             return path, body, inst
 
-        self.instances._create = Mock(side_effect=side_effect_func)
+        self.instances._create = mock.Mock(side_effect=side_effect_func)
+        nics = [{'net-id': '000'}]
         p, b, i = self.instances.create("test-name", 103, "test-volume",
-                                        ['db1', 'db2'], ['u1', 'u2'])
+                                        ['db1', 'db2'], ['u1', 'u2'],
+                                        datastore="datastore",
+                                        datastore_version="datastore-version",
+                                        nics=nics)
         self.assertEqual("/instances", p)
         self.assertEqual("instance", i)
         self.assertEqual(['db1', 'db2'], b["instance"]["databases"])
         self.assertEqual(['u1', 'u2'], b["instance"]["users"])
         self.assertEqual("test-name", b["instance"]["name"])
         self.assertEqual("test-volume", b["instance"]["volume"])
+        self.assertEqual("datastore", b["instance"]["datastore"]["type"])
+        self.assertEqual("datastore-version",
+                         b["instance"]["datastore"]["version"])
+        self.assertEqual(nics, b["instance"]["nics"])
         self.assertEqual(103, b["instance"]["flavorRef"])
 
-    def test__list(self):
-        self.instances.api.client.get = Mock(return_value=('resp', None))
-        self.assertRaises(Exception, self.instances._list, "url", None)
-
-        body = Mock()
-        body.get = Mock(return_value=[{'href': 'http://test.net/test_file',
-                                       'rel': 'next'}])
-        body.__getitem__ = Mock(return_value='instance1')
-        #self.instances.resource_class = Mock(return_value="instance-1")
-        self.instances.api.client.get = Mock(return_value=('resp', body))
-        _expected = [{'href': 'http://test.net/test_file', 'rel': 'next'}]
-        self.assertEqual(_expected, self.instances._list("url", None).links)
-
     def test_list(self):
-        def side_effect_func(path, inst, limit, marker):
-            return path, inst, limit, marker
-
-        self.instances._list = Mock(side_effect=side_effect_func)
+        page_mock = mock.Mock()
+        self.instances._paginated = page_mock
         limit = "test-limit"
         marker = "test-marker"
-        expected = ("/instances", "instances", limit, marker)
-        self.assertEqual(expected, self.instances.list(limit, marker))
+        self.instances.list(limit, marker)
+        page_mock.assert_called_with("/instances", "instances", limit, marker)
 
     def test_get(self):
         def side_effect_func(path, inst):
             return path, inst
 
-        self.instances._get = Mock(side_effect=side_effect_func)
+        self.instances._get = mock.Mock(side_effect=side_effect_func)
         self.assertEqual(('/instances/instance1', 'instance'),
                          self.instances.get(1))
 
     def test_delete(self):
-        resp = Mock()
+        resp = mock.Mock()
         resp.status_code = 200
         body = None
-        self.instances.api.client.delete = Mock(return_value=(resp, body))
+        self.instances.api.client.delete = mock.Mock(return_value=(resp, body))
         self.instances.delete('instance1')
         resp.status_code = 500
         self.assertRaises(Exception, self.instances.delete, 'instance1')
 
     def test__action(self):
-        body = Mock()
-        resp = Mock()
+        body = mock.Mock()
+        resp = mock.Mock()
         resp.status_code = 200
-        self.instances.api.client.post = Mock(return_value=(resp, body))
+        self.instances.api.client.post = mock.Mock(return_value=(resp, body))
         self.assertEqual('instance-1', self.instances._action(1, body))
 
-        self.instances.api.client.post = Mock(return_value=(resp, None))
-        self.assertEqual(None, self.instances._action(1, body))
+        self.instances.api.client.post = mock.Mock(return_value=(resp, None))
+        self.assertIsNone(self.instances._action(1, body))
 
     def _set_action_mock(self):
         def side_effect_func(instance_id, body):
@@ -156,7 +147,7 @@ class InstancesTest(TestCase):
 
         self._instance_id = None
         self._body = None
-        self.instances._action = Mock(side_effect=side_effect_func)
+        self.instances._action = mock.Mock(side_effect=side_effect_func)
 
     def test_resize_volume(self):
         self._set_action_mock()
@@ -176,8 +167,26 @@ class InstancesTest(TestCase):
         self.assertEqual(253, self._instance_id)
         self.assertEqual({'restart': {}}, self._body)
 
+    def test_modify(self):
+        resp = mock.Mock()
+        resp.status_code = 200
+        body = None
+        self.instances.api.client.put = mock.Mock(return_value=(resp, body))
+        self.instances.modify(123)
+        self.instances.modify(123, 321)
+        resp.status_code = 500
+        self.assertRaises(Exception, self.instances.modify, 'instance1')
 
-class InstanceStatusTest(TestCase):
+    def test_configuration(self):
+        def side_effect_func(path, inst):
+            return path, inst
+
+        self.instances._get = mock.Mock(side_effect=side_effect_func)
+        self.assertEqual(('/instances/instance1/configuration', 'instance'),
+                         self.instances.configuration(1))
+
+
+class InstanceStatusTest(testtools.TestCase):
 
     def test_constants(self):
         self.assertEqual("ACTIVE", instances.InstanceStatus.ACTIVE)
@@ -187,3 +196,5 @@ class InstanceStatusTest(TestCase):
         self.assertEqual("REBOOT", instances.InstanceStatus.REBOOT)
         self.assertEqual("RESIZE", instances.InstanceStatus.RESIZE)
         self.assertEqual("SHUTDOWN", instances.InstanceStatus.SHUTDOWN)
+        self.assertEqual("RESTART_REQUIRED",
+                         instances.InstanceStatus.RESTART_REQUIRED)
